#==============================================================================================================
# MODEL ASSUMPTIONS (frequentist mixed models)
# 1. species richness models
#   a. single explanatory variables 
#   b. multiple explanatory variables 
# 2. check robustness
# 3. Shannon diversity models
#   a. single explanatory variables 
#   b. multiple explanatory variables 
# 4. check robustness
#==============================================================================================================

# load data
source('./core_analysis.R')


# species richeness ---------------------------------------------------

    # single explanatory variables
        # protection
        plot(m_SR_protection)
        
        par(mfrow = c(3,2))
        plot(SR_dat$c_age_log, resid(m_SR_protection));abline(h = 0, lty = 2)
        plot(SR_dat$c_size_log_km2, resid(m_SR_protection));abline(h = 0, lty = 2)
        plot(SR_dat$ID, resid(m_SR_protection));abline(h = 0, lty = 2)
        plot(as.factor(SR_dat$protection), resid(m_SR_protection));abline(h = 0, lty = 2)
        plot(as.factor(SR_dat$fish_3groups), resid(m_SR_protection));abline(h = 0, lty = 2)
        plot(fitted(m_SR_protection), SR_dat$logRR);abline(c(0,1), lty = 2)
        par(mfrow = c(1,1))
        
        plot_model(m_SR_protection, type='diag')  
        
        # age
        plot(m_SR_age)
        
        par(mfrow = c(3,2))
        plot(SR_dat$c_age_log, resid(m_SR_age));abline(h = 0, lty = 2)
        plot(SR_dat$c_size_log_km2, resid(m_SR_age));abline(h = 0, lty = 2)
        plot(SR_dat$ID, resid(m_SR_age));abline(h = 0, lty = 2)
        plot(as.factor(SR_dat$protection), resid(m_SR_age));abline(h = 0, lty = 2)
        plot(as.factor(SR_dat$fish_3groups), resid(m_SR_age));abline(h = 0, lty = 2)
        plot(fitted(m_SR_age), SR_dat$logRR);abline(c(0,1), lty = 2)
        par(mfrow = c(1,1))
        
        plot_model(m_SR_age, type='diag')
        
        # size
        plot(m_SR_size)
        
        par(mfrow = c(3,2))
        plot(SR_dat$c_age_log, resid(m_SR_size));abline(h = 0, lty = 2)
        plot(SR_dat$c_size_log_km2, resid(m_SR_size));abline(h = 0, lty = 2)
        plot(SR_dat$ID, resid(m_SR_size));abline(h = 0, lty = 2)
        plot(as.factor(SR_dat$protection), resid(m_SR_size));abline(h = 0, lty = 2)
        plot(as.factor(SR_dat$fish_3groups), resid(m_SR_size));abline(h = 0, lty = 2)
        plot(fitted(m_SR_size), SR_dat$logRR);abline(c(0,1), lty = 2)
        par(mfrow = c(1,1))
        
        plot_model(m_SR_size, type='diag') 
  
    # multiple explanatory variables
        # all 3 variables without interaction
        plot(m_SR_3VwoI)
    
        par(mfrow = c(3,2))
        plot(SR_dat$c_age_log, resid(m_SR_3VwoI));abline(h = 0, lty = 2)
        plot(SR_dat$c_size_log_km2, resid(m_SR_3VwoI));abline(h = 0, lty = 2)
        plot(SR_dat$ID, resid(m_SR_3VwoI));abline(h = 0, lty = 2)
        plot(as.factor(SR_dat$protection), resid(m_SR_3VwoI));abline(h = 0, lty = 2)
        plot(as.factor(SR_dat$fish_3groups), resid(m_SR_3VwoI));abline(h = 0, lty = 2)
        plot(fitted(m_SR_3VwoI), SR_dat$logRR);abline(c(0,1), lty = 2)
        par(mfrow = c(1,1))
        
        plot_model(m_SR_3VwoI, type='diag')  
        vif(m_SR_3VwoI)
        
        # all 3 variables with all interactions
        plot(m_SR_3VwI)
        
        par(mfrow = c(3,2))
        plot(SR_dat$c_age_log, resid(m_SR_3VwI));abline(h = 0, lty = 2)
        plot(SR_dat$c_size_log_km2, resid(m_SR_3VwI));abline(h = 0, lty = 2)
        plot(SR_dat$ID, resid(m_SR_3VwI));abline(h = 0, lty = 2)
        plot(as.factor(SR_dat$protection), resid(m_SR_3VwI));abline(h = 0, lty = 2)
        plot(as.factor(SR_dat$fish_3groups), resid(m_SR_3VwI));abline(h = 0, lty = 2)
        plot(fitted(m_SR_3VwI), SR_dat$logRR);abline(c(0,1), lty = 2)
        par(mfrow = c(1,1))
        
        plot_model(m_SR_3VwI, type='diag')  
        vif(m_SR_3VwI)


# robustness check ------------------------------------------------------
    
    # 1. identify
    plot(fitted(m_SR_3VwI), SR_dat$logRR);abline(c(0,1), lty = 2)
    text(fitted(m_SR_3VwI), SR_dat$logRR, labels=SR_dat$ID, cex= 0.8, pos = 3)
    
    # 2. subset without outliers
    SR_dat_minusOutliers <- SR_dat %>% 
      filter(!str_detect(ID, "649")) %>% 
      filter(!str_detect (ID, "568"))
    
    # 3. fit new models
    m_SR_size_minusOutliers <- lmer(logRR ~ fish_3groups + c_size_log_km2 + (1 | ID),
                                    data = SR_dat_minusOutliers)
    m_SR_age_minusOutliers <- lmer(logRR ~ fish_3groups + c_age_log + (1 | ID),
                                   data = SR_dat_minusOutliers)
    m_SR_protection_minusOutliers <- lmer(logRR ~ fish_3groups + protection + (1 | ID),
                                          data = SR_dat_minusOutliers)
    m_SR_3VwoI_minusOutliers <- lmer(logRR ~ fish_3groups + protection + c_age_log + c_size_log_km2 + 
                                       (1 | ID), data = SR_dat_minusOutliers)
    m_SR_3VwI_minusOutliers <- lmer(logRR ~ (fish_3groups + protection + c_age_log + c_size_log_km2)^2 +
                                      (1 | ID), data = SR_dat_minusOutliers)
    
    # 4. check if critical assumptions look better
    plot(m_SR_protection_minusOutliers)
    plot_model(m_SR_protection_minusOutliers, type = "diag")
    plot(fitted(m_SR_protection_minusOutliers), SR_dat_minusOutliers$logRR);abline(c(0,1), lty = 2)
    
    plot(m_SR_age_minusOutliers)
    plot_model(m_SR_age_minusOutliers, type = "diag")
    plot(fitted(m_SR_age_minusOutliers), SR_dat_minusOutliers$logRR);abline(c(0,1), lty = 2)
    
    plot(m_SR_size_minusOutliers)
    plot_model(m_SR_size_minusOutliers, type = "diag")
    plot(fitted(m_SR_size_minusOutliers), SR_dat_minusOutliers$logRR);abline(c(0,1), lty = 2)
    
    plot(m_SR_3VwoI_minusOutliers)
    plot_model(m_SR_3VwoI_minusOutliers, type = "diag")
    plot(fitted(m_SR_3VwoI_minusOutliers), SR_dat_minusOutliers$logRR);abline(c(0,1), lty = 2)
    
    plot(m_SR_3VwI_minusOutliers)
    plot_model(m_SR_3VwI_minusOutliers, type = "diag")
    plot(fitted(m_SR_3VwI_minusOutliers), SR_dat_minusOutliers$logRR);abline(c(0,1), lty = 2)
    
    
    # 5. check if results are consistent
    summary(m_SR_size_minusOutliers) 
    summary(m_SR_age_minusOutliers) 
    summary(m_SR_protection_minusOutliers) 
    summary(m_SR_3VwoI_minusOutliers)
    summary(m_SR_3VwI_minusOutliers)


# shannon diversity ------------------------------------------------

    # single explanatory variables
        # protection
        plot(m_Shan_protection)
        
        par(mfrow = c(3,2))
        plot(Shan_dat$c_age_log, resid(m_Shan_protection));abline(h = 0, lty = 2)
        plot(Shan_dat$c_size_log_km2, resid(m_Shan_protection));abline(h = 0, lty = 2)
        plot(Shan_dat$ID, resid(m_Shan_protection));abline(h = 0, lty = 2)
        plot(as.factor(Shan_dat$protection), resid(m_Shan_protection));abline(h = 0, lty = 2)
        plot(as.factor(Shan_dat$fish_3groups), resid(m_Shan_protection));abline(h = 0, lty = 2)
        plot(fitted(m_Shan_protection), Shan_dat$logRR);abline(c(0,1), lty = 2)
        par(mfrow = c(1,1))
        
        plot_model(m_Shan_protection, type='diag')  
        
        # age
        plot(m_Shan_age)
        
        par(mfrow = c(3,2))
        plot(Shan_dat$c_age_log, resid(m_Shan_age));abline(h = 0, lty = 2)
        plot(Shan_dat$c_size_log_km2, resid(m_Shan_age));abline(h = 0, lty = 2)
        plot(Shan_dat$ID, resid(m_Shan_age));abline(h = 0, lty = 2)
        plot(as.factor(Shan_dat$protection), resid(m_Shan_age));abline(h = 0, lty = 2)
        plot(as.factor(Shan_dat$fish_3groups), resid(m_Shan_age));abline(h = 0, lty = 2)
        plot(fitted(m_Shan_age), Shan_dat$logRR);abline(c(0,1), lty = 2)
        par(mfrow = c(1,1))
        
        plot_model(m_Shan_age, type='diag')
        
        # size
        plot(m_Shan_size)
        
        par(mfrow = c(3,2))
        plot(Shan_dat$c_age_log, resid(m_Shan_size));abline(h = 0, lty = 2)
        plot(Shan_dat$c_size_log_km2, resid(m_Shan_size));abline(h = 0, lty = 2)
        plot(Shan_dat$ID, resid(m_Shan_size));abline(h = 0, lty = 2)
        plot(as.factor(Shan_dat$protection), resid(m_Shan_size));abline(h = 0, lty = 2)
        plot(as.factor(Shan_dat$fish_3groups), resid(m_Shan_size));abline(h = 0, lty = 2)
        plot(fitted(m_Shan_size), Shan_dat$logRR);abline(c(0,1), lty = 2)
        par(mfrow = c(1,1))
        
        plot_model(m_Shan_size, type='diag') 
    
    # multiple explanatory variables
        # all 3 variables without interaction
        plot(m_Shan_3VwoI)
        
        par(mfrow = c(3,2))
        plot(Shan_dat$c_age_log, resid(m_Shan_3VwoI));abline(h = 0, lty = 2)
        plot(Shan_dat$c_size_log_km2, resid(m_Shan_3VwoI));abline(h = 0, lty = 2)
        plot(Shan_dat$ID, resid(m_Shan_3VwoI));abline(h = 0, lty = 2)
        plot(as.factor(Shan_dat$protection), resid(m_Shan_3VwoI));abline(h = 0, lty = 2)
        plot(as.factor(Shan_dat$fish_3groups), resid(m_Shan_3VwoI));abline(h = 0, lty = 2)
        plot(fitted(m_Shan_3VwoI), Shan_dat$logRR);abline(c(0,1), lty = 2)
        par(mfrow = c(1,1))
        
        plot_model(m_Shan_3VwoI, type='diag')  
        vif(m_Shan_3VwoI)
        
        # all 3 variables with all interactions
        plot(m_Shan_3VwI)
        
        par(mfrow = c(3,2))
        plot(Shan_dat$c_age_log, resid(m_Shan_3VwI));abline(h = 0, lty = 2)
        plot(Shan_dat$c_size_log_km2, resid(m_Shan_3VwI));abline(h = 0, lty = 2)
        plot(Shan_dat$ID, resid(m_Shan_3VwI));abline(h = 0, lty = 2)
        plot(as.factor(Shan_dat$protection), resid(m_Shan_3VwI));abline(h = 0, lty = 2)
        plot(as.factor(Shan_dat$fish_3groups), resid(m_Shan_3VwI));abline(h = 0, lty = 2)
        plot(fitted(m_Shan_3VwI), Shan_dat$logRR);abline(c(0,1), lty = 2)
        par(mfrow = c(1,1))
        
        plot_model(m_Shan_3VwI, type='diag')  
        vif(m_Shan_3VwI)


# robustness check ------------------------------------------------------
    
    # 1. identify
    plot(fitted(m_Shan_3VwI), Shan_dat$logRR);abline(c(0,1), lty = 2)
    text(fitted(m_Shan_3VwI), Shan_dat$logRR, labels=rownames(Shan_dat), cex= 0.8, pos = 3)
    
    # 2. subset without outliers
    Shan_dat_minusOutliers <- Shan_dat %>% 
      slice(-11)
    
    # 3. fit new models
    m_Shan_size_minusOutliers <- lmer(logRR ~ fish_3groups + c_size_log_km2 + (1 | ID),
                                      data = Shan_dat_minusOutliers)
    m_Shan_age_minusOutliers <- lmer(logRR ~ fish_3groups + c_age_log + (1 | ID),
                                     data = Shan_dat_minusOutliers)
    m_Shan_protection_minusOutliers <- lmer(logRR ~ fish_3groups + protection + (1 | ID),
                                            data = Shan_dat_minusOutliers)
    m_Shan_3VwoI_minusOutliers <- lmer(logRR ~ fish_3groups + protection + c_age_log + c_size_log_km2 + 
                                         (1 | ID), data = Shan_dat_minusOutliers)
    m_Shan_3VwI_minusOutliers <- lmer(logRR ~ (fish_3groups + protection + c_age_log + c_size_log_km2)^2 +
                                        (1 | ID), data = Shan_dat_minusOutliers)
    
    # 4. check if critical assumptions look better
    plot(m_Shan_protection_minusOutliers)
    plot_model(m_Shan_protection_minusOutliers, type = "diag")
    plot(fitted(m_Shan_protection_minusOutliers), Shan_dat_minusOutliers$logRR);abline(c(0,1), lty = 2)
    
    plot(m_Shan_age_minusOutliers)
    plot_model(m_Shan_age_minusOutliers, type = "diag")
    plot(fitted(m_Shan_age_minusOutliers), Shan_dat_minusOutliers$logRR);abline(c(0,1), lty = 2)
    
    plot(m_Shan_size_minusOutliers)
    plot_model(m_Shan_size_minusOutliers, type = "diag")
    plot(fitted(m_Shan_size_minusOutliers), Shan_dat_minusOutliers$logRR);abline(c(0,1), lty = 2)
    
    plot(m_Shan_3VwoI_minusOutliers)
    plot_model(m_Shan_3VwoI_minusOutliers, type = "diag")
    plot(fitted(m_Shan_3VwoI_minusOutliers), Shan_dat_minusOutliers$logRR);abline(c(0,1), lty = 2)
    
    plot(m_Shan_3VwI_minusOutliers)
    plot_model(m_Shan_3VwI_minusOutliers, type = "diag")
    plot(fitted(m_Shan_3VwI_minusOutliers), Shan_dat_minusOutliers$logRR);abline(c(0,1), lty = 2)
    
    # 5. check if results are consistent
    summary(m_Shan_size_minusOutliers) 
    summary(m_Shan_age_minusOutliers) 
    summary(m_Shan_protection_minusOutliers) 
    summary(m_Shan_3VwoI_minusOutliers) 
    summary(m_Shan_3VwI_minusOutliers) 