#===============================================================================
# COMPARATIVE FIGURES
# 1. histograms log response ratio
# 2. log response ratio of species richness as a function of size and age
#===============================================================================

# load data
source('./modeling.R')


# Annotations (create labels) --------------------------------------------------

annA <- grobTree(textGrob("a", x=0.05,  y=0.90, hjust=0, gp=gpar(fontsize=20, fontface="bold")))
annA.s <- grobTree(textGrob("a", x=0.2,  y=0.90, hjust=0, gp=gpar(fontsize=20, fontface="bold")))
annB <- grobTree(textGrob("b", x=0.05,  y=0.90, hjust=0, gp=gpar(fontsize=20, fontface="bold")))
annB.s <- grobTree(textGrob("b", x=0.2,  y=0.90, hjust=0, gp=gpar(fontsize=20, fontface="bold")))
annC <- grobTree(textGrob("c", x=0.05,  y=0.90, hjust=0, gp=gpar(fontsize=20, fontface="bold")))
annD <- grobTree(textGrob("d", x=0.05,  y=0.90, hjust=0, gp=gpar(fontsize=20, fontface="bold")))


# histograms log response ratio --------------------------------

    # richness
        # Linear mixed model
        est_null <- summary(m_SR_null)
        CI_null <- confint.merMod(m_SR_null, method = "profile", oldNames = FALSE)
        CI_null <- CI_null %>%
          as.data.frame(t(CI_null)) %>%
          add_column(protection = c("del", "del", "y")) %>%
          filter(!str_detect(protection, "del")) %>%
          add_column(mean = c(est_null$coefficients[1])) %>%
          dplyr::rename("lci" = "2.5 %", "uci" = "97.5 %")
        
        logRR_hist_SR2 <- ggplot(SR_dat, aes(x=logRR)) +
          geom_histogram( binwidth=0.02, fill="grey", color="grey", size = 1) +
          geom_rect(data=CI_null, aes(xmin=CI_null[1,1], xmax=CI_null[1,2], ymin=0, ymax=7), fill="black", alpha=0.5, inherit.aes = FALSE) +
          geom_segment(aes(x = 0, y = 0, xend = 0, yend = 7), size=0.5, linetype="longdash") + # 0 line
          geom_segment(aes(x = CI_null[1,4], y = 0, xend = CI_null[1,4], yend = 7), size=0.8, color = "black") + # mean
          annotation_custom(annA) +
          ggtitle("Linear mixed model") +
          xlab("Log response ratio") +
          ylab("No. MPAs") +
          coord_cartesian(xlim = c(NA, 1.5)) +
          theme(panel.background = element_rect(fill = 'white'),
                panel.grid.major = element_line(colour = "lightgrey"),
                panel.grid.minor = element_line(colour = "white"),
                panel.border = element_rect(fill = NA,colour = "black"), 
                plot.background = element_rect(fill = 'white'),
                strip.background = element_rect(fill = "white"),
                plot.title = element_text(size = 12),
                axis.text.x = element_text(color="black"),
                axis.text.y = element_text(color="black"))
        
        # Meta-analytic linear mixed model
        est_null_brm <- summary(brm_SR_null)
        est_null_brm <- est_null_brm[["fixed"]]
        
        logRR_hist_brm <- ggplot(SR_dat_brms, aes(x=logRR)) +
          geom_histogram( binwidth=0.02, fill="grey", color="grey", size = 1) +
          geom_rect(data=CI_null, aes(xmin=est_null_brm[1,3], xmax=est_null_brm[1,4], ymin=0, ymax=6), fill="black", alpha=0.5, inherit.aes = FALSE) +
          geom_segment(aes(x = 0, y = 0, xend = 0, yend = 6), size=0.5, linetype="longdash") + # 0 line
          geom_segment(aes(x = est_null_brm[1,1], y = 0, xend = est_null_brm[1,1], yend = 6), size=0.8, color = "black") + # mean
          annotation_custom(annB) +
          ggtitle("Meta-analytic linear mixed model") +
          xlab("Log response ratio") +
          ylab("No. MPAs") +
          coord_cartesian(xlim = c(NA, 1.5)) +
          theme(panel.background = element_rect(fill = 'white'),
                panel.grid.major = element_line(colour = "lightgrey"),
                panel.grid.minor = element_line(colour = "white"),
                panel.border = element_rect(fill = NA,colour = "black"), 
                plot.background = element_rect(fill = 'white'),
                strip.background = element_rect(fill = "white"),
                plot.title = element_text(size = 12),
                axis.text.x = element_text(color="black"),
                axis.text.y = element_text(color="black"))
    
    # Shannon
        # Linear mixed model
        est_null_Shan <- summary(m_Shan_null)
        CI_null_Shan <- confint.merMod(m_Shan_null, method = "profile", oldNames = FALSE)
        CI_null_Shan <- CI_null_Shan %>%
          as.data.frame(t(CI_null_Shan)) %>%
          add_column(protection = c("del", "del", "y")) %>%
          filter(!str_detect(protection, "del")) %>%
          add_column(mean = c(est_null_Shan$coefficients[1])) %>%
          dplyr::rename("lci" = "2.5 %", "uci" = "97.5 %")
        
        logRR_hist_Shan2 <- ggplot(Shan_dat, aes(x=logRR)) +
          geom_histogram( binwidth=0.03, fill="grey", color="grey", size = 1) +
          geom_rect(data=CI_null_Shan, aes(xmin=CI_null_Shan[1,1], xmax=CI_null_Shan[1,2], ymin=0, ymax=4), fill="black", alpha=0.5, inherit.aes = FALSE) +
          geom_segment(aes(x = 0, y = 0, xend = 0, yend = 4), size=0.5, linetype="longdash") + #0
          geom_segment(aes(x = CI_null_Shan[1,4], y = 0, xend = CI_null_Shan[1,4], yend = 4), size=0.8, color = "black") + #mean
          annotation_custom(annC) +
          ggtitle("Linear mixed model") +
          xlab("Log response ratio") +
          ylab("No. MPAs") +
          theme(panel.background = element_rect(fill = 'white'),
                panel.grid.major = element_line(colour = "lightgrey"),
                panel.grid.minor = element_line(colour = "white"),
                panel.border = element_rect(fill = NA,colour = "black"), 
                plot.background = element_rect(fill = 'white'),
                strip.background = element_rect(fill = "white"),
                plot.title = element_text(size = 12),
                axis.text.x = element_text(color="black"),
                axis.text.y = element_text(color="black"))
        
        # Meta-analytic linear mixed model
        est_null_brm_Shan <- summary(brm_Shan_null)
        est_null_brm_Shan <- est_null_brm_Shan[["fixed"]]
        
        logRR_hist_brm_Shan <- ggplot(Shan_dat_brms, aes(x=logRR)) +
          geom_histogram( binwidth=0.03, fill="grey", color="grey", size = 1) +
          geom_rect(data=CI_null_Shan, aes(xmin=est_null_brm_Shan[1,3], xmax=est_null_brm_Shan[1,4], ymin=0, ymax=3), fill="black", alpha=0.5, inherit.aes = FALSE) +
          geom_segment(aes(x = 0, y = 0, xend = 0, yend = 3), size=0.5, linetype="longdash") + # 0 line
          geom_segment(aes(x = est_null_brm_Shan[1,1], y = 0, xend = est_null_brm_Shan[1,1], yend = 3), size=0.8, color = "black") + # mean
          annotation_custom(annD) +
          ggtitle("Meta-analytic linear mixed model") +
          xlab("Log response ratio") +
          ylab("No. MPAs") +
          coord_cartesian(xlim = c(NA, NA)) +
          theme(panel.background = element_rect(fill = 'white'),
                panel.grid.major = element_line(colour = "lightgrey"),
                panel.grid.minor = element_line(colour = "white"),
                panel.border = element_rect(fill = NA,colour = "black"), 
                plot.background = element_rect(fill = 'white'),
                strip.background = element_rect(fill = "white"),
                plot.title = element_text(size = 12),
                axis.text.x = element_text(color="black"),
                axis.text.y = element_text(color="black"))
    
    lay <- rbind(c(1,2))
    
    compare_plot1 <- grid.arrange(logRR_hist_SR2, logRR_hist_brm, layout_matrix = lay, top = textGrob("Species richness",gp=gpar(fontface="bold")))
    compare_plot2 <- grid.arrange(logRR_hist_Shan2, logRR_hist_brm_Shan, layout_matrix = lay, top = textGrob("Shannon entropy",gp=gpar(fontface="bold")))
    
    pdf("mod_compare_logRR_hist.pdf", width = 8, height = 6.5)
    grid.arrange(compare_plot1, compare_plot2)
    dev.off()


# log response ratio of species richness as a function of size and age -----------------------
    
    # size
        # Linear mixed model
        effects_size <- effects::effect(term = "c_size_log_km2", mod = m_SR_size, 
                                        xlevels = list(c_size_log_km2 = c(-8.011828977,	-2.441577895,-0.007964539,2.451274364,4.929518990)))
        x_size <- as.data.frame(effects_size)
        x_size$size_km2 <- c(0.008,2.100,23.940,280.000,3337.690)
        
        point_size.c1 <- ggplot() + 
          geom_ribbon(data= x_size, aes(x = size_km2, ymin=lower, ymax=upper), alpha= 0.4, fill="darkgrey") +
          geom_point(data=SR_dat, aes(size_km2, logRR)) + 
          geom_line(data=x_size, aes(x=size_km2, y=fit), color="black", lwd = 1.25) +
          geom_hline(yintercept = 0, lty = 1, color = "black", size = 0.5) +
          scale_x_continuous(trans = 'log10') +
          coord_cartesian(xlim = c(0.2, NA)) +
          ylim(c(-0.7, 1.2)) +
          ylab(element_blank()) +
          xlab(expression(paste("Area in ", km^2, ""))) +
          theme(panel.background = element_rect(fill = 'white'),
                panel.grid.major = element_line(colour = "lightgrey"),
                panel.grid.minor = element_line(colour = "white"),
                panel.border = element_rect(fill = NA,colour = "black"), 
                plot.background = element_rect(fill = 'white'),
                strip.background = element_rect(fill = "white"),
                plot.title = element_text(size = 12),
                axis.text.y = element_blank(),
                axis.ticks.y=element_blank(),
                axis.text.x = element_text(color="black"),
                axis.text.y = element_text(color="black"))
        
        point_size.c2 <- ggplot() + 
          geom_ribbon(data= x_size, aes(x = size_km2, ymin=lower, ymax=upper), alpha= 0.4, fill="darkgrey") +
          geom_point(data=SR_dat, aes(size_km2, logRR)) + 
          geom_line(data=x_size, aes(x=size_km2, y=fit), color="black", lwd = 1.25) +
          geom_hline(yintercept = 0, lty = 1, color = "black", size = 0.5) +
          annotation_custom(annA.s) +
          ylim(c(-0.7, 1.2)) +
          scale_x_continuous(trans = 'log10', breaks=c(0.008)) +
          coord_cartesian(xlim = c(0.005, 0.015)) +
          labs(y= "Log response ratio", x = "") +
          theme(panel.background = element_rect(fill = 'white'),
                panel.grid.major = element_line(colour = "lightgrey"),
                panel.grid.minor = element_line(colour = "white"),
                panel.border = element_rect(fill = NA,colour = "black"), 
                plot.background = element_rect(fill = 'white'),
                strip.background = element_rect(fill = "white"),
                plot.title = element_text(size = 12),
                axis.text.x = element_text(color="black"),
                axis.text.y = element_text(color="black"))
        
        lay.size <- rbind(c(1,1,2,2,2,2,2,2))
        
        sizeplot.unweight <- grid.arrange(point_size.c2, point_size.c1, layout_matrix = lay.size, top = grid::textGrob("Linear mixed model", x = 0, hjust = -0.28))
        
        # Meta-analytic linear mixed model
        effects_brm_size <- conditional_effects(brm_SR_size, effects = 'c_size_log_km2', re_formula = NA, method = 'fitted')  
        
        s1 <- log(1) - mean(log(dat_brms_expla$size_km2), na.rm = TRUE)
        s10 <- log(10) - mean(log(dat_brms_expla$size_km2), na.rm = TRUE)
        s100 <- log(100) - mean(log(dat_brms_expla$size_km2), na.rm = TRUE)
        s1000 <- log(1000) - mean(log(dat_brms_expla$size_km2), na.rm = TRUE)
        
        point_size_brm.c1 <- ggplot() + 
          geom_ribbon(data= effects_brm_size$c_size_log_km2, aes(x = c_size_log_km2, ymin=lower__, ymax=upper__), alpha= 0.4, fill="darkgrey") +
          geom_point(data=SR_dat_brms, aes(c_size_log_km2, logRR)) + 
          geom_line(data=effects_brm_size$c_size_log_km2, aes(x=c_size_log_km2, y=estimate__), color="black", lwd = 1.25) +
          geom_hline(yintercept = 0, lty = 1, color = "black", size = 0.5) +
          scale_x_continuous(breaks = c(s1, s10, s100, s1000), 
                             labels = c("1", "10", "100", "1000")) +
          coord_cartesian(xlim = c(-4.510335817, NA)) +
          ylim(c(-0.7, 1.2)) +
          ylab(element_blank()) +
          xlab(expression(paste("Area in ", km^2, ""))) +
          theme(panel.background = element_rect(fill = 'white'),
                panel.grid.major = element_line(colour = "lightgrey"),
                panel.grid.minor = element_line(colour = "white"),
                panel.border = element_rect(fill = NA,colour = "black"), 
                plot.background = element_rect(fill = 'white'),
                strip.background = element_rect(fill = "white"),
                plot.title = element_text(size = 12),
                axis.text.y = element_blank(),
                axis.ticks.y=element_blank(),
                axis.text.x = element_text(color="black"),
                axis.text.y = element_text(color="black"))
        
        point_size_brm.c2 <- ggplot() + 
          geom_ribbon(data= effects_brm_size$c_size_log_km2, aes(x = c_size_log_km2, ymin=lower__, ymax=upper__), alpha= 0.4, fill="darkgrey") +
          geom_point(data=SR_dat_brms, aes(c_size_log_km2, logRR)) + 
          geom_line(data=effects_brm_size$c_size_log_km2, aes(x=c_size_log_km2, y=estimate__), color="black", lwd = 1.25) +
          geom_hline(yintercept = 0, lty = 1, color = "black", size = 0.5) +
          annotation_custom(annB.s) +
          ylim(c(-0.7, 1.2)) +
          scale_x_continuous(breaks = c(-7.729211642), labels = c("0.008")) +
          coord_cartesian(xlim = c(-8.25, -7.25)) +
          labs(y= "Log response ratio", x = "") +
          theme(panel.background = element_rect(fill = 'white'),
                panel.grid.major = element_line(colour = "lightgrey"),
                panel.grid.minor = element_line(colour = "white"),
                panel.border = element_rect(fill = NA,colour = "black"), 
                plot.background = element_rect(fill = 'white'),
                strip.background = element_rect(fill = "white"),
                plot.title = element_text(size = 12),
                axis.text.x = element_text(color="black"),
                axis.text.y = element_text(color="black"))
    
        lay.size <- rbind(c(1,1,2,2,2,2,2,2))
        
        sizeplot.weight <- grid.arrange(point_size_brm.c2, point_size_brm.c1, layout_matrix = lay.size, top = grid::textGrob("Meta-analytic linear mixed model", x = 0, hjust = -0.32)) 
                                        # bottom = grid::textGrob(expression(paste("Area in ", km^2, "")), y = 0, vjust = -1.2))
        
    # age
        # Linear mixed model
        effects_age <- effects::effect(term = "c_age_log", mod = m_SR_age, 
                                       xlevels = list(c_age_log = c(-2.152037071,-0.611592030,-0.115155144,0.577992037,1.393741539)))
        x_age <- as.data.frame(effects_age)
        x_age$mpa_age <- c(1.5,7.0,11.5,23,52)
        
        point_age <- ggplot() + 
          geom_ribbon(data= x_age, aes(x = mpa_age, ymin=lower, ymax=upper), alpha= 0.4, fill="darkgrey") +
          geom_point(data=SR_dat, aes(mpa_age, logRR)) + 
          geom_line(data=x_age, aes(x=mpa_age, y=fit), color="black", lwd = 1.25) +
          geom_hline(yintercept = 0, lty = 1, color = "black", size = 0.5) +
          annotation_custom(annC) +
          coord_cartesian(ylim = c(-0.7, 1.2)) +
          scale_x_continuous(trans = 'log10') +
          ggtitle("Linear mixed model") +
          labs(y= "Log response ratio", x = "Duration of protection in years") +
          theme(panel.background = element_rect(fill = 'white'),
                panel.grid.major = element_line(colour = "lightgrey"),
                panel.grid.minor = element_line(colour = "white"),
                panel.border = element_rect(fill = NA,colour = "black"), 
                plot.background = element_rect(fill = 'white'),
                strip.background = element_rect(fill = "white"),
                plot.title = element_text(size = 12),
                axis.text.x = element_text(color="black"),
                axis.text.y = element_text(color="black"))
        
        # Meta-analytic linear mixed model
        effects_brm_age <- conditional_effects(brm_SR_age, effects = 'c_age_log', re_formula = NA, method = 'fitted')
        
        a3 <- log(3) - mean(log(dat_brms_expla$mpa_age), na.rm = TRUE)
        a10 <- log(10) - mean(log(dat_brms_expla$mpa_age), na.rm = TRUE)
        a30 <- log(30) - mean(log(dat_brms_expla$mpa_age), na.rm = TRUE)
        
        point_age_brm <- ggplot() + 
          geom_ribbon(data= effects_brm_age$c_age_log, aes(x = c_age_log, ymin=lower__, ymax=upper__), alpha= 0.4, fill="darkgrey") +
          geom_point(data=SR_dat_brms, aes(c_age_log, logRR)) + 
          geom_line(data=effects_brm_age$c_age_log, aes(x=c_age_log, y=estimate__), color="black", lwd = 1.25) +
          geom_hline(yintercept = 0, lty = 1, color = "black", size = 0.5) +
          annotation_custom(annD) +
          coord_cartesian(ylim = c(-0.7, 1.2)) +
          scale_x_continuous(breaks = c(a3, a10, a30), 
                             labels = c("3", "10", "30")) +
          ggtitle("Meta-analytic linear mixed model") +
          labs(y= "Log response ratio", x = expression(paste("Duration of protection in years"))) +
          theme(panel.background = element_rect(fill = 'white'),
                panel.grid.major = element_line(colour = "lightgrey"),
                panel.grid.minor = element_line(colour = "white"),
                panel.border = element_rect(fill = NA,colour = "black"), 
                plot.background = element_rect(fill = 'white'),
                strip.background = element_rect(fill = "white"),
                plot.title = element_text(size = 12),
                axis.text.x = element_text(color="black"),
                axis.text.y = element_text(color="black"))
    
    lay <- rbind(c(1,2))
    
    compare_plot3 <- grid.arrange(sizeplot.unweight, sizeplot.weight, layout_matrix = lay, top = textGrob("Protected area size",gp=gpar(fontface="bold")))
    compare_plot4 <- grid.arrange(point_age, point_age_brm, layout_matrix = lay, top = textGrob("Time since establishment",gp=gpar(fontface="bold")))
    
    pdf("mod_compare_age_size.pdf", width = 8, height = 6.5)
    grid.arrange(compare_plot3, compare_plot4)
    dev.off()
